Learn R Programming

fdaMocca (version 0.1-2)

criteria.mocca: AIC, BIC, entropy for a functional clustering model

Description

Function to extract the information criteria AIC and BIC, as well as the average Shannon entropy over all functional objects, for a fitted functional clustering mocca. The Shannon entropy is computed over the posterior probability distribution of belonging to a specific cluster given the functional object (see Arnqvist and Sjöstedt de Luna, 2019, for further details).

Usage

criteria.mocca(x)

Value

A table with the AIC, BIC and Shannon entropy values of the fitted model.

Arguments

x

fitted model objects of class mocca as produced by mocca().

Author

Per Arnqvist

References

Arnqvist, P., and Sjöstedt de Luna, S. (2019). Model based functional clustering of varved lake sediments. arXiv preprint arXiv:1904.10265.

See Also

logLik.mocca, mocca

Examples

Run this code
## see examples in mocca() 

Run the code above in your browser using DataLab